#
# spec file for package gnome-remote-desktop
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global systemd_unit gnome-remote-desktop.service

%define freerdp_version 2.2.0

Name:           gnome-remote-desktop
Version:        41.3
Release:        150400.3.3.1
Summary:        GNOME Remote Desktop screen sharing service
License:        GPL-2.0-or-later
Group:          System/Management
URL:            https://gitlab.gnome.org/GNOME/gnome-remote-desktop
Source0:        %{name}-%{version}.tar.xz

BuildRequires:  meson >= 0.36.0
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(ffnvcodec)
BuildRequires:  pkgconfig(freerdp-client2) >= %{freerdp_version}
BuildRequires:  pkgconfig(freerdp-server2) >= %{freerdp_version}
BuildRequires:  pkgconfig(freerdp2) >= %{freerdp_version}
BuildRequires:  pkgconfig(fuse3) >= 3.9.1
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.68
BuildRequires:  pkgconfig(glib-2.0) >= 2.68
BuildRequires:  pkgconfig(gstreamer-1.0) >= 1.10.0
BuildRequires:  pkgconfig(gstreamer-video-1.0) >= 1.10.0
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libpipewire-0.3) >= 0.3.0
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libvncclient)
BuildRequires:  pkgconfig(libvncserver)
BuildRequires:  pkgconfig(libvncserver) >= 0.9.10
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(winpr2) >= %{freerdp_version}
BuildRequires:  pkgconfig(xkbcommon) >= 1.0.0
%{?systemd_ordering}

Requires:       pipewire >= 0.3.0

%description
GNOME Remote Desktop is a remote desktop and screen sharing service for the
GNOME desktop environment.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name}

%post
%systemd_user_post %{systemd_unit}

%preun
%systemd_user_preun %{systemd_unit}

%postun
%systemd_user_postun_with_restart %{systemd_unit}

%files
%license COPYING
%doc README
%{_libexecdir}/gnome-remote-desktop-daemon
%{_userunitdir}/gnome-remote-desktop.service
%{_datadir}/glib-2.0/schemas/org.gnome.desktop.remote-desktop.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.desktop.remote-desktop.enums.xml
%{_datadir}/%{name}/

%files lang -f %{name}.lang

%changelog
* Mon Jun  6 2022 qkzhu@suse.com
- Update to version 41.3:
  * build: Bump version to 41.3
  * Add Icelandic translation
* Thu Dec  9 2021 bjorn.lie@gmail.com
- Update to version 41.2:
  + stream: Add method to disconnect proxy signals
  + session:
  - Stop trying to stop the session, when it is already destroyed
  - Disconnect num/caps lock changed signals when stopping
  - Fix small style issue
  - Only handle Selection* signals when clipboard is enabled
  + settings:
  - Clear settings of type string before setting new values
  - Don't leak credentials, when username or password is NULL
  - Set error if username or password is NULL
  + clipboard-rdp:
  - Make a warning message a little bit more explicit
  - Make SelectionTransfer requests async
  - Fix error message, when runtime directory creation fails
  - Fix small style issues
  + clipboard:
  - Split up SelectionTransfer handling
  - Also clear GMutexes and GConds on destruction
  + context: Clear proxies before setting new proxies
  + daemon: Also clear context on destruction
  + rdp/nw-auto:
  - Only create ping source if required and non-existent
  - Also clear GMutexes on destruction
  + rdp-graphics-pipeline: Also clear gfx_mutex on destruction
  + rdp-fuse-clipboard: Also clear GMutexes on destruction
  + rdp-event-queue: Also clear event_mutex on destruction
  + rdp-pipewire-stream: Also clear frame_mutex on destruction
  + session-rdp: Also clear GMutexes and GConds on destruction
  + Updated translations.
* Sat Oct 30 2021 bjorn.lie@gmail.com
- Update to version 41.1:
  + vnc-pipewire-stream: Take frame data from pending frame, when
    needed
  + rdp-pipewire-stream: Take frame data from pending frame, when
    needed
  + rdp/rdpgfx: Unref surface serial after looking up surface
    context
  + rdp-graphics-pipeline: Fix small style issue
  + rdp-fuse-clipboard:
  - Fix potential race when accessing FuseFile path
  - Fix small style issue
  + clipboard-rdp: Always check return value of ConvertFromUnicode
  + session-rdp: Only signal GCond, when all encode jobs are
    complete
* Mon Sep 20 2021 bjorn.lie@gmail.com
- Update to version 41.0:
  + Updated translations.
- Set .changes to be filled via service file, since upstream fails
  to provide a changelog/NEWS file.
* Wed Sep 15 2021 dimstar@opensuse.org
- Update to version 41.rc:
  + No changelog provided by upstream.
- Add pkgconfig(ffnvcodec) BuildRequires: new dependency.
* Wed Sep 15 2021 bjorn.lie@gmail.com
- Update to version 40.2:
  + rdp-fuse-clipboard: Handle FUSE lifetime object in FUSE thread
  + tests: Use bash from environment instead of hardcoded path
- Changes from version 40.1:
  + clipboard-rdp:
  - Also output client capabilities
  - Add dummy handling for the Temporary Directory PDU
  - Advertise clipboard data locking
  - Adapt to data locking changes
  - Add APIs to lock/unlock the clients clipboard data
  - Implement clipboard data locking
  - clipboard-rdp: Use g_idle_add() instead of g_timeout_add()
  + rdp: Allow submitting clipDataIds for FileContentsRequests
  + rdp-fuse-clipboard:
  - Remove the old API
  - Use notify_delete() instead of notify_inval_entry()
  - Be more verbose with file range requests
  - Read files until the very end
  - Handle all file lists via clipDataIds
  + rdp-sam: Remove stray trailing whitespaces
  + pipewire-stream: Don't leak GSource's
  + build:
  - Add missing new line
  - Explicitly depend on glib >= 2.68
* Sun Mar 21 2021 dimstar@opensuse.org
- Update to version 40.0:
  + rdp: Add support for FreeRDP 2.3, support 2.3, requires at
    least 2.2.
  + Manu bugfixes.
- Add pkgconfig(freerdp-client2), pkgconfig(freerdp-server2),
  pkgconfig(fuse3), pkgconfig(libvncclient),
  pkgconfig(libvncserver), and pkgconfig(xkbcommon) BuildRequires:
  better align with what meson looks for.
- Change _service file to point to the proper upstream git repo
  (gitlab.gnome.org/GNOME/gnome-remote-desktop).
- Drop gnutls-anontls.patch,
  0001-vnc-Copy-pixels-using-the-right-destination-stride.patch
  0001-vnc-Drop-frames-if-client-is-gone.patch: fixed upstream:
  fixed upstream.
* Fri Jan  8 2021 fcrozat@suse.com
- Update to version 0.1.9:
  + add support for RDP (requires freerdp2)
  + many bugfixes
- Add pkgconfig(freerdp2), pkgconfig(winpr2), pkgconfig(cairo) as
  BuildRequires.
- Bump pipewire minimum version to 0.3.0.
- Update url to GNOME main project.
- Add0001-vnc-Drop-frames-if-client-is-gone.patch
  Avoid race condition on disconnect (glgo#GNOME/gnome-remote-desktop#43)
- Add gnutls-anontls.patch (Fedora), requires patched libVNCServer.
- Add 0001-vnc-Copy-pixels-using-the-right-destination-stride.patch:
  Copy using the right destination stride (glgo#GNOME/gnome-remote-desktop!21)
* Sun Mar 22 2020 bjorn.lie@gmail.com
- Update to version 0.1.8:
  + Port to pipewire-0.3.
- Replace pkgconfig(libpipewire-0.2) with
  pkgconfig(libpipewire-0.3) BuildRequires.
* Fri Oct 18 2019 bjorn.lie@gmail.com
- Update to version 0.1.7:
  + vnc-pipewire-stream:
  - Assume no bitmap offset means no bitmap change.
  - Close session when disconnected.
  + vnc:
  - Request cursor sprite as PipeWire metadata.
  - Detach source when client is gone.
  + session/vnc:
  - Set rfbScreenPtr pointer earlier.
  - Update server format earlier too.
  - Always set pixel format translate functions.
  - Don't requeue close session idle.
  + Use type safety feature of glib 2.58.
  + meson.build: Use default C standard.
  + Remove autogen.sh and Makefile.
  + meson.build: Bump pipewire requirement to 0.2.2.
- Drop pipewire-bump.patch: Fixed upstream.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 0.1.6:
  + Please see https://gitlab.gnome.org/jadahl/gnome-remote-desktop
- Add pkgconfig(libnotify), pkgconfig(libpipewire-0.2) and
  pkgconfig(libsecret-1) BuildRequires: New dependencies.
- Drop gnome-remote-desktop-bad-meson-option.patch: Fixed upstream.
- Add pipewire-bump.patch: Fix build with new pipewire.
* Thu May 17 2018 hpj@suse.com
- Initial package.
